@@ -1,2 +1,2 @@
 """ Tools for ovmf and armvirt edk2 firmware volumes """
-__all__ = [ "edk2", "linux", "dump", "vars" ]
+__all__ = [ "dump", "vars", "host", "efi", "varstore" ]
